from django.contrib import admin
from .models import UsersBan

class UsersBanModel(admin.ModelAdmin):
    list_display = ['user','ban',]
    list_filter = ('ban',)
    search_fields = ('user__user','user__first_name','user__last_name')

admin.site.register(UsersBan,UsersBanModel)



from django.db import models
from django.conf import settings

class UsersBan(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL,
                             verbose_name="User name",
                             help_text="Choose Username")

    ban = models.BooleanField(default=False,
                              verbose_name="Ban",
                              help_text="Users Bans")

    class Meta:
        verbose_name_plural = "Ban Management"
        ordering = ('user',)

    def __str__(self):
        return '{}'.format(self.user)



from .models import UsersBan
from django.shortcuts import render


class BanManagement():
    """Users Management"""

    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        response = self.get_response(request)

        if(UsersBan.objects.all().filter(ban=True,user_id=request.user.id)):
            return render(request,'ban.html')
        else:
            return response


from distutils.core import setup

setup(
    name='DjangoBan',
    version='1.8.0',
    packages=['ban', 'ban.migrations'],
    url='https://github.com/AliYmn/DjangoBan',
    license='MIT',
    author='aliyaman',
    author_email='aliymn.db@gmail.com',
    description='Django User Ban Management ',
    download_url='https://github.com/AliYmn/DjangoBan',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
